==> kdesvn-1.4.1.tar.bz2: kdesvn-1.4.1/src/kdesvn_events.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://kdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef KDESVN_EVENTS_H
#define KDESVN_EVENTS_H

#include <qevent.h>
#include "src/svnqt/svnqt_defines.hpp"

class FillCacheStatusEvent:public QEvent
{
    public:
        FillCacheStatusEvent(qlonglong current,qlonglong max);
        qlonglong current()const{return m_current;}
        qlonglong max()const{return m_max;}
    private:
        qlonglong m_current,m_max;
};

class DataEvent:public QEvent
{
    public:
        DataEvent(QEvent::Type);

        void setData(void*data);
        void*data()const;
    private:
        void*_data;
};

#endif

==> kdesvn_1.6.0.orig.tar.bz2: kdesvn-1.6.0/src/kdesvn_events.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://kdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef KDESVN_EVENTS_H
#define KDESVN_EVENTS_H

#include <qevent.h>
#include "src/svnqt/svnqt_defines.h"

class FillCacheStatusEvent:public QEvent
{
    public:
        FillCacheStatusEvent(qlonglong current,qlonglong max);
        qlonglong current()const{return m_current;}
        qlonglong max()const{return m_max;}
    private:
        qlonglong m_current,m_max;
};

class DataEvent:public QEvent
{
    public:
        DataEvent(QEvent::Type);

        void setData(void*data);
        void*data()const;
    private:
        void*_data;
};

#endif
